@@ -3,23 +3,26 @@ require Exporter;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw/tokenize
                 decomment
+		remove_quotes
                 @fields
-                $trad_comment_re
-                $cxx_comment_re
+		$include
+		$include_local
+                $char_const_re
                 $comment_re
                 $cpp_re
-                $char_const_re
-                $operator_re
-                $number_re
-                $word_re
+		$cvar_re
+                $cxx_comment_re
+		$decimal_re
                 $grammar_re
+		$hex_re
+                $number_re
+		$octal_re
+                $operator_re
+                $reserved_re
                 $single_string_re
                 $string_re
-                $reserved_re
-		$include_local
-		$include
-		remove_quotes
-		$cvar_re
+                $trad_comment_re
+                $word_re
                /;
 
 our %EXPORT_TAGS = (
@@ -28,7 +31,7 @@ our %EXPORT_TAGS = (
 
 use warnings;
 use strict;
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 # http://www.open-std.org/JTC1/SC22/WG14/www/docs/n1256.pdf
 # 6.4.1
@@ -261,6 +264,16 @@ my $deref = qr!
 		  [\*&]+\s*$word_re
 	      !x;
 
+my $array_re = qr!
+		     $word_re
+		     \s*
+		     \[
+		     \s*
+		     $word_re
+		     \s*
+		     \]
+		 !x;
+
 my $member = qr!
 		     (?:
 			 (?:
@@ -269,6 +282,8 @@ my $member = qr!
 			     \.
 			 )
 			 $word_re
+		     |
+			 $array_re
 		     )
 	       !x;
 
@@ -282,6 +297,8 @@ our $cvar_re = qr!
 		     # A word or a dereferenced value in brackets
 		     (?:
 			 $word_re
+		     |
+			 $array_re
 		     |
 			 \(\s*$deref\)
 		     )
